@@ -1,6 +1,6 @@
 #include <gtk/gtk.h>
 
-void main_dlg_init( GtkWidget* dlg );
+GtkWidget* main_dlg_new();
 
 void
 on_apply_clicked                       (GtkButton       *button,
@@ -18,6 +18,10 @@ void
 on_remove_theme_clicked                (GtkButton       *button,
                                         gpointer         user_data);
 
+void
+on_cursor_size_changed                 (GtkHScale       *cursorsizescale,
+                                        gpointer         user_data);
+
 void
 on_tb_style_changed                    (GtkComboBox     *combobox,
                                         gpointer         user_data);
